DROP PROCEDURE IF EXISTS `sp_get_email_body`;

go

CREATE PROCEDURE `sp_get_email_body`(in email_id INT,in selection INT)
BEGIN
CASE selection 
WHEN 1 THEN
	SELECT tblEMails.Mailbody from tblEMails WHERE tblEMails.MailID = email_id;	
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_email_update`;

go

CREATE PROCEDURE `sp_email_update`(in email_id INT, in selection INT,out status VARCHAR(10))
BEGIN
DECLARE CONTINUE HANDLER FOR SQLSTATE '23000' SET status='error';
CASE selection 
WHEN 1 THEN
UPDATE `tblEMails` SET `RetryCount`= 0 WHERE `MailID`= email_id;      
SET status='success';
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_dns_server_insert`;

go

CREATE PROCEDURE `sp_dns_server_insert`(in website_id INT, in website_zone_name VARCHAR(100), in server_ip VARCHAR(250), in selection INT, out status VARCHAR(10))
BEGIN
DECLARE server_role_id INT;
DECLARE CONTINUE HANDLER FOR SQLSTATE '23000' SET status= 'error';
SET status='success';
CASE selection 
WHEN 1 THEN
select   ServerRoleID INTO server_role_id FROM tblServerRoles INNER JOIN
   tblRoles ON tblServerRoles.RoleID = tblRoles.RoleID INNER JOIN
   tblServers ON tblServerRoles.ServerID = tblServers.ServerID where  (tblRoles.Role = 'dnsserver') AND (tblServers.ServerIP = server_ip);
   Insert into
   tblDNSServer(WebsiteID,ServerRoleID,WebsiteZoneName)
values(website_id,server_role_id,website_zone_name);
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_get_email_types`;

go

CREATE PROCEDURE `sp_get_email_types`(in display_level INT,in selection INT)
BEGIN
CASE selection 
WHEN 1 THEN
	SELECT 	tblMailTemplates.Subject,tblMailTemplates.DisplayIndex,tblMailTemplates.DisplayLevel FROM tblMailTemplates WHERE DisplayLevel IN (display_level,2) ORDER BY (DisplayIndex); 
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_bandwidth_select`;

go

CREATE PROCEDURE `sp_bandwidth_select`(in id INT, in selection INT)
BEGIN
CASE selection 
WHEN 1 THEN 
	select SUM(BandwidthUsage) from tblBandwidth where WebsiteID IN (select WebsiteID from tblWebsites where OwnerID=id);
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_mail_domain_select`;

go

CREATE PROCEDURE `sp_mail_domain_select`(in field1 INT,in field2 VARCHAR(100), in selection INT)
BEGIN
CASE selection 
WHEN 1 THEN
	SELECT * FROM `tblMailDomains` WHERE `MailDomainID` = field1;
WHEN 2 THEN
	SELECT * FROM `tblMailDomains` WHERE `MailDomainName` = field2;
WHEN 3 THEN
	SELECT * FROM `tblMailDomains` WHERE `WebsiteID` = field1;
WHEN 4 THEN
	SELECT WebsiteID FROM `tblMailDomains` WHERE `MailDomainID` = field1;
WHEN 5 THEN 
	select SUM(DiskSpaceUsage) from tblMailDomains where WebsiteID IN (select WebsiteID from tblWebsites where OwnerID=field1);
WHEN 6 THEN 
	select OwnerID from tblWebsites where WebsiteID = (select WebsiteID from tblMailDomains where `MailDomainName` = field2);
WHEN 7 THEN 
	select SUM(DiskSpaceUsage) from tblMailDomains where WebsiteID=field1;
WHEN 50 THEN
	SELECT COUNT(MailDomainID) from tblMailDomains;
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_database_select`;

go

CREATE PROCEDURE `sp_database_select`(in database_id INT, in selection INT)
BEGIN
CASE selection 
WHEN 1 THEN
	SELECT * FROM `tblDatabases` WHERE `DatabaseID`= database_id;
WHEN 2 THEN
	SELECT `ServerID` FROM `tblServerRoles` WHERE `ServerRoleID`=(SELECT `ServerRoleID` FROM `tblUsersServers` WHERE `UserID`=(SELECT `OwnerID` FROM `tblWebsites` Where `WebsiteID`=(SELECT `WebsiteID` FROM `tblDatabases` WHERE `DatabaseID`=database_id)));
WHEN 3 THEN
	SELECT `UserID`,`UserName` FROM `tblUsers` WHERE `UserID`=(SELECT `OwnerID` FROM `tblWebsites` Where `WebsiteID`=(SELECT `WebsiteID` FROM `tblDatabases` WHERE `DatabaseID`=database_id));
WHEN 4 THEN
	SELECT `WebsiteID` FROM `tblDatabases` WHERE `DatabaseID`= database_id; 
WHEN 5 THEN 
	select SUM(DiskSpaceUsage) from tblDatabases where WebsiteID IN (select WebsiteID from tblWebsites where OwnerID=database_id);
WHEN 6 THEN 
	select SUM(DiskSpaceUsage) from tblDatabases where WebsiteID=database_id;
WHEN 50 THEN 
	SELECT COUNT(DatabaseID) FROM tblDatabases;
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_websites_select`;

go

CREATE PROCEDURE `sp_websites_select`(in field1 INT,in field2 VARCHAR(100), in selection INT)
BEGIN
CASE selection 
WHEN 1 THEN
	set @query = CONCAT("SELECT `WebsiteID`,`WebsiteName`,`DiskSpaceUsage`  FROM `tblWebsites` WHERE `OwnerID` IN (",field2,")");
	PREPARE STMT FROM @query;
	EXECUTE STMT;
WHEN 2 THEN
	set @query = CONCAT("SELECT tblWebsites.WebsiteID,tblWebsites.WebsiteName,tblUsers.UserName FROM `tblWebsites` INNER JOIN tblUsers ON tblWebsites.OwnerID=tblUsers.UserID WHERE tblWebsites.OwnerID IN (",field2,")");
	PREPARE STMT FROM @query;
	EXECUTE STMT;
WHEN 3 THEN
	SELECT (SELECT ServerRoleID FROM tblUsersServers WHERE UserID=(SELECT OwnerID FROM tblWebsites WHERE WebsiteID=field1)) AS ServerRoleID, ServerID, ServerIP FROM tblServers WHERE ServerID=(SELECT ServerID FROM tblServerRoles WHERE ServerRoleID=(SELECT ServerRoleID FROM tblUsersServers WHERE UserID=(SELECT OwnerID FROM tblWebsites WHERE WebsiteID=field1)));
WHEN 4 THEN
	SELECT UserID,UserName FROM tblUsers WHERE UserID = (SELECT OwnerID FROM tblWebsites WHERE WebsiteID=field1);
WHEN 5 THEN
	SELECT `WebsiteName` FROM tblWebsites WHERE `WebsiteID`=field1;
WHEN 6 THEN
	SELECT `WebsiteID`,`WebsiteName` FROM tblWebsites WHERE `OwnerID` IN (SELECT UserID FROM tblUsers WHERE OwnerID=field1);
WHEN 7 THEN
	SELECT `WebsiteID`,`WebsiteName` FROM tblWebsites WHERE `OwnerID`=field1;
WHEN 8 THEN
	SELECT SUM(DiskSpaceUsage) FROM tblWebsites WHERE OwnerID=field1;
WHEN 9 THEN
	select count(WebsiteID) as TotalWebsites from tblWebsites,tblUsers,tblUsersServers,tblServerRoles,tblServers Where (tblUsers.isdeleted =0 or tblUsers.isdeleted is null) and tblWebsites.IsSubDomain = 0 and tblWebsites.OwnerID = tblUsers.UserID and tblUsers.UserID = tblUsersServers.UserID and tblUsersServers.ServerRoleID = 		tblServerRoles.ServerRoleID and tblServerRoles.ServerID = tblServers.ServerID and tblServers.ServerID = field1;
WHEN 10 THEN
	SELECT WebsiteID FROM `tblWebsites` WHERE `WebsiteName`= field2;
WHEN 11 THEN
	SELECT * from tblWebsites WHERE WebsiteID = field1;
WHEN 12 THEN
	SELECT SUM(BandwidthUsage) FROM tblBandwidth WHERE WebsiteID=field1;
WHEN 50 THEN
	SELECT COUNT(WebsiteID) FROM tblWebsites;
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_database_select1`;

go

CREATE PROCEDURE `sp_database_select1`(in param varchar(256), in selection INT)
BEGIN
CASE selection 
WHEN 1 THEN
	SELECT `DatabaseID` FROM `tblDatabases` WHERE `DatabaseName`= param;
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_plans_select`;

go

CREATE PROCEDURE `sp_plans_select`(in field1 INT,in field2 varchar(1000), in selection INT)
BEGIN
CASE selection 
WHEN 1 THEN
	SELECT * FROM `tblPlans` WHERE `PlanID`= field1 AND `IsDeleted`=0;
WHEN 2 THEN
	SELECT * FROM `tblPlans` WHERE `UserID`= field1 AND `PlanName`= field2 AND `IsDeleted`= 0;
WHEN 3 THEN
	SELECT `PlanID`,`PlanName` FROM `tblPlans` WHERE `UserID`= field1 AND `IsDeleted`=0 AND `Status`=1;
WHEN 4 THEN
	SELECT `PlanID`,`PlanName` FROM `tblPlans` WHERE `UserID`= field1 AND `PlanModeID`=2 AND `IsDeleted`=0 AND `Status`=1;
WHEN 5 THEN
	SELECT `PlanName` FROM `tblPlans` WHERE `PlanID`= field1;
WHEN 6 THEN
	SELECT COUNT(`PlanID`) FROM `tblPlans` WHERE `UserID`= field1 AND `IsDeleted`=0;
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_sold_plans_select1`;

go

CREATE PROCEDURE `sp_sold_plans_select1`(in field1 INT, in field2 INT, in selection INT)
BEGIN
CASE selection 
WHEN 1 THEN
	SELECT MAX(`SoldPlanID`) FROM `tblSoldPlans` WHERE `PlanID`=field2 AND `UserID`=field1; 
WHEN 2 THEN
	 SELECT tblSoldPlans.PlanID,tblPlanResourceQty.QtyIncluded FROM tblSoldPlans INNER JOIN tblPlanResourceQty ON tblSoldPlans.PlanID=tblPlanResourceQty.PlanID WHERE tblSoldPlans.UserID=field1 AND tblPlanResourceQty.ResourceID=field2;
WHEN 3 THEN
	 SELECT PlanID,UserID FROM tblSoldPlans WHERE SoldPlanID=field1;
WHEN 4 THEN
	 SELECT * FROM tblSoldPlans WHERE PlanID=field1;
END CASE;
END

go

DROP PROCEDURE IF EXISTS `sp_plan_mail_server_type_delete`;

go

CREATE PROCEDURE `sp_plan_mail_server_type_delete`(in plan_id INT,out status VARCHAR(10))
BEGIN
DECLARE CONTINUE HANDLER FOR SQLSTATE '23000' SET status='error';
SET status='success';
DELETE FROM `tblPlanMailServerType` WHERE `PlanID`=plan_id;
END

go

